package com.cesys.cebo.cebomsr;

/**
 * Class to use when setting multiple outputs simultaneous. Direct construction is prohibited,
 * as the count of the the various elements varies from device type to device type. Instances
 * must be generated calling {@link Device}.createOutputFrame().
 *
 * @author Thomas Hoppe
 */
public final class OutputFrame {
	private final float[] _analogValues;
	private final int[] _digitalValues;

	float[] getAnalogValues() {
		return _analogValues;
	}

	int[] getDigitalValues() {
		return _digitalValues;
	}

	OutputFrame(int anac, int digc) {
		_analogValues = new float[anac];
		_digitalValues = new int[digc];
	}

	/**
	 * Define value that should be set on the specified digital port.
	 * @param index Zero based index of port to specify.
	 * @param value Value to set at this port.
	 */
	public void setDigitalPort(int index, int value) {
		_digitalValues[index] = value;
	}

	/**
	 * Define value that should be set on the specified analog output.
	 * @param index Zero based index of output to specify.
	 * @param value Value to set at this output.
	 */
	public void setAnalogOutput(int index, float value) {
		_analogValues[index] = value;
	}

	public String toString() {
		StringBuilder sb = new StringBuilder();
		sb.append("OutputFrame: \n");
		for (int i = 0; i < _analogValues.length; ++i)
			sb.append(String.format("AnalogOutput #%d = %.2f V \n", i, _analogValues[i]));
		for (int i = 0; i < _digitalValues.length; ++i)
			sb.append(String.format("DigitalPort #%d = %d (0x%02x) \n", i, _digitalValues[i], _digitalValues[i]));
		return sb.toString();
	}
}
